@@ -57,6 +57,7 @@ class ChainedCommand(click.Command):
         """ Strip some RST markup from the help text for CLI display.  Assumes no grid tables. """
         if not hasattr(self, 'click_wrap_text'):
             self.click_wrap_text = click.formatting.wrap_text
+        # TODO: copy homonim sub_strings
         sub_strings = {
             '\b\n': '\n\b',  # convert from RST friendly to click literal (unwrapped) block marker
             ':option:': '',  # strip ':option:'
@@ -246,7 +247,7 @@ def cli(ctx, verbose, quiet):
 
 
 # TODO: add clear docs on what is piped out of or into each command.
-
+# TODO: use cloup and linear help layout.  move lists of option values from command docting to corresponding option help
 
 # config command
 @click.command(cls=ChainedCommand, context_settings=dict(auto_envvar_prefix='GEEDIM'))
@@ -354,13 +355,15 @@ cli.add_command(config)
     '-c', '--collection', type=click.STRING, required=True, callback=_collection_cb,
     help=f'Earth Engine image collection to search. geedim or EE collection names can be used.'
 )
-@click.option('-s', '--start-date', type=click.DateTime(), required=True, help='Start date (UTC).')
-@click.option('-e', '--end-date', type=click.DateTime(), required=True, help='End date (UTC).')
+@click.option('-s', '--start-date', type=click.DateTime(), required=False, default=None, help='Start date (UTC).')
+@click.option(
+    '-e', '--end-date', type=click.DateTime(), required=False, default=None,
+    show_default='one day after ``--start-date``', help='End date (UTC).'
+)
 @bbox_option
 @click.option(
     '-r', '--region', type=click.Path(exists=True, dir_okay=False, allow_dash=True), callback=_region_cb,
-    help='Region defined by geojson polygon or raster file. Use "-" to read geojson from stdin.  One of '
-    ':option:`--bbox` or :option:`--region` is required.'
+    help='Region defined by geojson polygon or raster file. Use "-" to read geojson from stdin.'
 )
 @click.option(
     '-fp', '--fill-portion', type=click.FloatRange(min=0, max=100), default=0, show_default=True,
@@ -372,18 +375,28 @@ cli.add_command(config)
     'for the specified collection, :option:`--cloudless-portion` will operate like :option:`--fill-portion`.'
 )
 @click.option(
-    '-o', '--output', type=click.Path(exists=False, dir_okay=False, writable=True), default=None,
+    '-cf', '--custom-filter', type=click.STRING, default=None,
+    help='Custom image property filter e.g. "property > value".  Quote delimiters are required.'
+)
+@click.option(
+    '-ap', '--add-property', 'add_props', type=click.STRING, default=None, multiple=True,
+    help='Additional image property name(s) to include in search results.'
+)
+@click.option(
+    '-op', '--output', type=click.Path(exists=False, dir_okay=False, writable=True), default=None,
     help='JSON file to write search results to.'
 )
 @click.pass_obj
-def search(obj, collection, start_date, end_date, bbox, region, fill_portion, cloudless_portion, output):
+def search(
+    obj, collection, start_date, end_date, bbox, region, fill_portion, cloudless_portion, custom_filter, output,
+    add_props
+):
     # @formatter:off
     """
     Search for images.
 
-    Search a Google Earth Engine image collection for images, filtering by date, region and portion of
-    filled pixels.  Cloud/shadow-free (cloudless) portion filtering is supported on the following
-    collections:
+    Search a Google Earth Engine image collection for images, based on date, region, portion of filled pixels, and
+    custom filters.  Cloud/shadow-free (cloudless) portion filtering is supported on the following collections:
     \b
 
         ===========  ===========================
@@ -400,10 +413,10 @@ def search(obj, collection, start_date, end_date, bbox, region, fill_portion, cl
         s2-sr-hm     COPERNICUS/S2_SR_HARMONIZED
         ===========  ===========================
 
-    A search region must be specified with either the ``--bbox`` or ``--region`` option.
+    The search must be filtered with at least one of the ``--start-date``, ``--bbox`` or ``--region`` options.
 
     Note that filled/cloudless portions are not taken from the granule metadata, but are calculated as portions of the
-    specified search region for better accuracy.
+    specified search region for improved accuracy.
     \b
 
     Examples
@@ -416,24 +429,30 @@ def search(obj, collection, start_date, end_date, bbox, region, fill_portion, cl
     Search the Landsat-9 collection for images with a cloud/shadow free portion of at least 50%::
 
         geedim search -c l9-c2-l2 -s 2022-01-01 -e 2022-03-01 --bbox 23 -34 23.2 -33.8 --cloudless-portion 50
+
+    Search the Landsat-8 collection for images whose `CLOUD_COVER_LAND` property is less than 50%, and include the
+    `CLOUD_COVER_LAND`, and `CLOUD_COVER` image properties in the search results::
+
+        geedim search -c l8-c2-l2 -s 2022-01-01 -e 2022-05-01 --bbox 23 -34 23.2 -33.8 -cf "CLOUD_COVER_LAND<50" -ap CLOUD_COVER_LAND -ap CLOUD_COVER
     """
     # @formatter:on
-    if not obj.region:
-        raise click.BadOptionUsage('region', 'Either pass --region or --bbox')
+    if not obj.region and not start_date:
+        raise click.BadOptionUsage(
+            'start-date / region', 'Specify at least --start-time and/or a region with --region/--bbox'
+        )
 
     # create collection wrapper and search
-    gd_collection = MaskedCollection.from_name(collection)
+    gd_collection = MaskedCollection.from_name(collection, add_props=add_props)
     logger.info('')
-    label = (
-        f'Searching for {collection} images between {start_date.strftime("%Y-%m-%d")} and '
-        f'{end_date.strftime("%Y-%m-%d")}: '
-    )
+
+    label = f'Searching for {collection} images: '
     with Spinner(label=label, leave=' '):
         gd_collection = gd_collection.search(
             start_date, end_date, obj.region, fill_portion=fill_portion, cloudless_portion=cloudless_portion,
-            **obj.cloud_kwargs
+            custom_filter=custom_filter, **obj.cloud_kwargs
         )
-        num_images = len(gd_collection.properties)  # retrieve search result properties from EE
+        # retrieve search result properties from EE
+        num_images = gd_collection.properties
 
     if num_images == 0:
         logger.info('No images found\n')
