@@ -16,13 +16,20 @@
 
 import zipfile
 from io import BytesIO
+import threading
+from contextlib import contextmanager
+import sys
 
 import numpy as np
 import requests
+import rasterio as rio
 from rasterio import Affine, MemoryFile
 from rasterio.windows import Window
 from tqdm.auto import tqdm
 
+# lock to prevent concurrent calls to ee.Image.getDownloadURL in python 3.10
+_ee_lock = threading.Lock()
+
 
 class Tile:
 
@@ -48,15 +55,29 @@ class Tile:
         """ rasterio tile window into the source image. """
         return self._window
 
+    @staticmethod
+    @contextmanager
+    def _concurrent_download_url():
+        """
+        Context manager to acquire a thread lock if the python version is 3.10.  Works around a bug where concurrent
+        calls to ee.Image.getDownloadURL() cause a core dump (in python 3.10).
+        """
+        if sys.version_info.major == 3 and sys.version_info.minor == 10:
+            with _ee_lock:
+                yield None
+        else:
+            yield None
+
     def _get_download_url_response(self, session=None):
         """ Get tile download url and response. """
         session = session if session else requests
-        url = self._exp_image.ee_image.getDownloadURL(
-            dict(
-                crs=self._exp_image.crs, crs_transform=tuple(self._transform)[:6], dimensions=self._shape[::-1],
-                filePerBand=False, fileFormat='GeoTIFF'
+        with self._concurrent_download_url():
+            url = self._exp_image.ee_image.getDownloadURL(
+                dict(
+                    crs=self._exp_image.crs, crs_transform=tuple(self._transform)[:6], dimensions=self._shape[::-1],
+                    filePerBand=False, fileFormat='GeoTIFF'
+                )
             )
-        )
         return session.get(url, stream=True), url
 
     def download(self, session=None, response=None, bar: tqdm = None):
@@ -104,7 +125,7 @@ class Tile:
         ext_buffer = BytesIO(zip_file.read(zip_file.filelist[0]))
 
         # read the geotiff with a rasterio memory file
-        with MemoryFile(ext_buffer) as mem_file:
+        with rio.Env(GDAL_NUM_THREADS='ALL_CPUs', GTIFF_FORCE_RGBA=False), MemoryFile(ext_buffer) as mem_file:
             with mem_file.open() as ds:
                 array = ds.read()
                 if (array.dtype == np.dtype('float32')) or (array.dtype == np.dtype('float64')):
